OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Contraseña incorrecta",
    "No user supplied" : "No se especificó un usuario",
    "Authentication error" : "Error de autenticación",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Por favor facilite una contraseña de recuperación de administrador, sino podrían perderse todos los datos de usuario",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor compruebe la contraseña e inténtelo de nuevo.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "El backend no admite cambios de contraseña, pero la clave de cifrado del usuario ha sido actualizada satisfactoriamente.",
    "Unable to change password" : "No se ha podido cambiar la contraseña",
    "Enabled" : "Habilitado",
    "Not enabled" : "No habilitado",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalando y actualizando aplicaciones via app store o Nube compartida Federada",
    "Federated Cloud Sharing" : "Compartido en Cloud Federado",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL está usando una versión desactualizada %s (%s). Por favor, actualice su sistema operativo o funciones tales como %s no funcionará de forma fiable.",
    "A problem occurred, please check your log files (Error: %s)" : "Ocurrió un problema, por favor verifique los archivos de registro (Error: %s)",
    "Migration Completed" : "Migración finalizada",
    "Group already exists." : "El grupo ya existe.",
    "Unable to add group." : "No se pudo agregar el grupo.",
    "Unable to delete group." : "No se pudo eliminar el grupo.",
    "log-level out of allowed range" : "Nivel de autenticación fuera del rango permitido",
    "Saved" : "Guardado",
    "test email settings" : "probar configuración de correo electrónico",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocurrió un problema al enviar el mensaje de correo electrónico. Revise su configuración. (Error: %s)",
    "Email sent" : "Correo electrónico enviado",
    "You need to set your user email before being able to send test emails." : "Tiene que configurar su dirección de correo electrónico antes de poder enviar mensajes de prueba.",
    "Invalid mail address" : "Dirección de correo inválida",
    "A user with that name already exists." : "Ya existe un usuario con ese nombre.",
    "Unable to create user." : "No se pudo crear el usuario.",
    "Your %s account was created" : "Se ha creado su cuenta de %s",
    "Unable to delete user." : "No se pudo eliminar el usuario.",
    "Forbidden" : "Prohibido",
    "Invalid user" : "Usuario no válido",
    "Unable to change mail address" : "No se pudo cambiar la dirección de correo electrónico",
    "Email saved" : "Correo electrónico guardado",
    "Your full name has been changed." : "Se ha cambiado su nombre completo.",
    "Unable to change full name" : "No se puede cambiar el nombre completo",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Security & setup warnings" : "Avisos de seguridad y configuración",
    "Sharing" : "Compartiendo",
    "Server-side encryption" : "Cifrado en el servidor",
    "External Storage" : "Almacenamiento externo",
    "Cron" : "Cron",
    "Email server" : "Servidor de correo electrónico",
    "Log" : "Registro",
    "Tips & tricks" : "Sugerencias y trucos",
    "Updates" : "Actualizaciones",
    "Couldn't remove app." : "No se pudo eliminar la aplicación.",
    "Language changed" : "Idioma cambiado",
    "Invalid request" : "Petición no válida",
    "Admins can't remove themself from the admin group" : "Los administradores no se pueden eliminar a ellos mismos del grupo de administrador",
    "Unable to add user to group %s" : "No se pudo añadir el usuario al grupo %s",
    "Unable to remove user from group %s" : "No se pudo eliminar al usuario del grupo %s",
    "Couldn't update app." : "No se pudo actualizar la aplicación.",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "¿Está seguro de querer agregar \"{domain}\" como un dominio de confianza?",
    "Add trusted domain" : "Agregar dominio de confianza",
    "Migration in progress. Please wait until the migration is finished" : "Migración en curso. Por favor, espere hasta que la migración esté finalizada.",
    "Migration started …" : "Migración iniciada...",
    "Sending..." : "Enviando...",
    "Official" : "Oficial",
    "Approved" : "Aprobado",
    "Experimental" : "Experimental",
    "All" : "Todos",
    "No apps found for your version" : "No se han encontrado aplicaciones para su versión",
    "The app will be downloaded from the app store" : "La app debe ser descargada desde una app store",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Las aplicaciones oficiales se desarrollan por y dentro de la comunidad ownCloud. Estas ofrecen una funcionalidad crucial en ownCloud y están listas para su uso en producción. ",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Las aplicaciones aprobadas las desarrollan desarrolladores de confianza y han pasado un control de seguridad superficial. Estas se mantienen activamente en un repositorio de código abierto y sus encargados las consideran estables para un uso normal.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Esta aplicación no está verificada por problemas de seguridad además de ser reciente o conocida por ser inestable. Instálela bajo su propio riesgo.",
    "Update to %s" : "Actualizar a %s",
    "_You have %n app update pending_::_You have %n app updates pending_" : ["Tiene %n actualización de app pendiente","Tiene %n actualizaciones de app pendientes"],
    "Please wait...." : "Espere, por favor....",
    "Error while disabling app" : "Error mientras se desactivaba la aplicación",
    "Disable" : "Desactivar",
    "Enable" : "Activar",
    "Error while enabling app" : "Error mientras se activaba la aplicación",
    "Error: this app cannot be enabled because it makes the server unstable" : "Error: Esta App no puede habilitarse porque el servidor se volveria inestable.",
    "Error: could not disable broken app" : "Error: No puedo deshabilitar la App dañada.",
    "Error while disabling broken app" : "Error mientras deshabilitaba la App dañada",
    "Updating...." : "Actualizando...",
    "Error while updating app" : "Error mientras se actualizaba la aplicación",
    "Updated" : "Actualizado",
    "Uninstalling ...." : "Desinstalando...",
    "Error while uninstalling app" : "Error al desinstalar la aplicación",
    "Uninstall" : "Desinstalar",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación ha sido activada pero necesita ser actualizada. Seras redirigido a la pagina de actualizariones en 5 segundos.",
    "App update" : "Actualización de aplicación",
    "No apps found for {query}" : "No se han encontrado apps para {query}",
    "Disconnect" : "Desconectar",
    "Error while loading browser sessions and device tokens" : "Error al cargar sesiones de navegador y \"tokens\" de dispositivos",
    "Error while creating device token" : "Error al crear \"token\" de dispositivo",
    "Error while deleting the token" : "Error al detectar el \"token\"",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ha ocurrido un error. Por favor, cargue un certificado PEM codificado en ASCII.",
    "Valid until {date}" : "Válido hasta {date}",
    "Delete" : "Eliminar",
    "An error occurred: {message}" : "Ocurrió un error: {message}",
    "Select a profile picture" : "Seleccionar una imagen de perfil",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña pasable",
    "Good password" : "Contraseña buena",
    "Strong password" : "Contraseña muy buena",
    "Groups" : "Grupos",
    "Unable to delete {objName}" : "No es posible eliminar {objName}",
    "Error creating group: {message}" : "Error creando el grupo: {message}",
    "A valid group name must be provided" : "Se debe dar un nombre válido para el grupo ",
    "deleted {groupName}" : "{groupName} eliminado",
    "undo" : "deshacer",
    "no group" : "sin grupo",
    "never" : "nunca",
    "deleted {userName}" : "borrado {userName}",
    "add group" : "añadir grupo",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Cambiar la contraseña provocará pérdida de datos porque la recuperación de datos no está disponible para este usuario",
    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
    "Error creating user: {message}" : "Error creando el usuario: {message}",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
    "A valid email must be provided" : "Se debe brindar una dirección de correo electrónico válida ",
    "__language_name__" : "Castellano",
    "Unlimited" : "Ilimitado",
    "Personal info" : "Información personal",
    "Sessions" : "Sesiones",
    "App passwords" : "App de contraseñas",
    "Sync clients" : "Sincronizar clientes",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Todo (Información, Avisos, Errores, debug y problemas fatales)",
    "Info, warnings, errors and fatal issues" : "Información, Avisos, Errores y problemas fatales",
    "Warnings, errors and fatal issues" : "Advertencias, errores y problemas fatales",
    "Errors and fatal issues" : "Errores y problemas fatales",
    "Fatal issues only" : "Problemas fatales solamente",
    "None" : "Ninguno",
    "Login" : "Iniciar sesión",
    "Plain" : "Plano",
    "NT LAN Manager" : "Gestor de NT LAN",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php parece que no está configurado correctamente para solicitar las variables de entorno del sistema. La prueba con getenv(\"PATH\") sólo retorna una respuesta vacía.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Por favor revisa la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentación de instalación ↗</a> para notas de configuración PHP y la configuración PHP de tu servidor, especialmente cuando se está usando php-fpm",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Se ha habilitado la configuración de sólo lectura. Esto evita tener que ajustar algunas configuraciones a través de la interfaz web. Además, el archivo debe hacerse modificable manualmente para cada actualización.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado para eliminar bloques de documentos en línea. Esto hará que varias aplicaciones principales no estén accesibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Probablemente esto venga a causa de la caché o un acelerador, tales como Zend OPcache o eAccelerator.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Su base de datos no se ejecuta con el nivel de aislamiento de transacción \"READ COMMITED\" . Ésto puede causar problemas cuando múltiples acciones se ejecutan en paralelo.",
    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Su servidor está operando con Microsoft Windows. Le recomendamos GNU/Linux encarecidamente para disfrutar una experiencia óptima como usuario.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s una versión inferior %2$s está instalada, por razones de estabilidad y rendimiento, se recomienda actualizar a la versión %1$s más reciente .",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "No se ha encontrado el modulo PHP 'fileinfo'. Le recomendamos encarecidamente que habilite este módulo para obtener mejores resultados con la detección de tipos MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "El bloqueo de archivos transaccional está desactivado, esto podría conducir a problemas con 'race conditions'. Activa 'filelocking.enabled' en 'config.php' para solucionar esos problemas. Mira la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentación ↗</a> para más información.",
    "System locale can not be set to a one which supports UTF-8." : "No se puede escoger una configuración regional que soporte UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Esto significa que puede haber problemas con ciertos caracteres en los nombres de los archivos.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Es muy recomendable instalar los paquetes necesarios para poder soportar una de las siguientes configuraciones regionales: %s. ",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si su instalación no está ubicada en la raíz del dominio y usa el cron del sistema, puede haber problemas al generarse los URL. Para evitarlos, configure la opción \"overwrite.cli.url\" en su archivo config.php para que use la ruta de la raíz del sitio web de su instalación (sugerencia: \"%s\")",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "No fue posible ejecutar cronjob vía CLI. Han aparecido los siguientes errores técnicos:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Por favor, compruebe de nuevo las <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guías de instalación ↗</a>, y comprueba por cualquier error o advertencia en el  <a href=\"#log-section\">Registro</a>",
    "All checks passed." : "Ha pasado todos los controles",
    "Open documentation" : "Abrir Documentación",
    "Allow apps to use the Share API" : "Permitir a las aplicaciones utilizar la API de Compartición",
    "Allow users to share via link" : "Permite a los usuarios compartir por medio de enlaces",
    "Allow public uploads" : "Permitir subidas públicas",
    "Enforce password protection" : "Forzar la protección por contraseña.",
    "Set default expiration date" : "Establecer fecha de caducidad predeterminada",
    "Allow users to send mail notification for shared files" : "Permitir a los usuarios enviar mensajes de notificación para ficheros compartidos",
    "Expire after " : "Caduca luego de",
    "days" : "días",
    "Enforce expiration date" : "Imponer fecha de caducidad",
    "Allow resharing" : "Permitir recompartición",
    "Allow sharing with groups" : "Permitir compartir con grupos",
    "Restrict users to only share with users in their groups" : "Restringe a los usuarios a compartir solo con otros usuarios en sus grupos",
    "Allow users to send mail notification for shared files to other users" : "Permitir a los usuarios enviar notificaciones por correo electrónico de los archivos compartidos a otros usuarios",
    "Exclude groups from sharing" : "Excluye grupos de compartir",
    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir contenidos compartidos, pero no podrán, pero no podrán iniciarlos.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Permitir autocompletación del nombre de usuario en diálogos de compartición. Si está deshabilitado, se requiere introducir el nombre de usuario.",
    "Last cron job execution: %s." : "Cron se ejecutó por última vez: %s",
    "Last cron job execution: %s. Something seems wrong." : "Cron se ejecutó por última vez: %s. Algo va mal.",
    "Cron was not executed yet!" : "¡Cron aún no ha sido ejecutado!",
    "Execute one task with each page loaded" : "Ejecutar una tarea con cada página cargada",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php se registra en un servicio webcron para llamar a cron.php cada 15 minutos a través de HTTP.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Usar el servicio cron del sistema para llamar al archivo cron.php cada 15 minutos.",
    "Enable server-side encryption" : "Habilitar cifrado en el servidor",
    "Please read carefully before activating server-side encryption: " : "Por favor lea cuidadosamente antes de activar el cifrado del lado del servidor.",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que el cifrado está habilitado, todos los archivos subidos al servidor desde ese punto en adelante se cifrarán en reposo en el servidor. Sólo será posible desactivar el cifrado en una fecha posterior si el módulo de cifrado activado soporta esa función, y todas las condiciones previas (por ejemplo, el establecimiento de una clave de recuperación) se cumplan.",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "El cifrado en sí solo no garantiza la seguridad del sistema. Por favor, consulte la documentación de ownCloud para obtener más información acerca de cómo funciona la aplicación de cifrado, y los casos de uso compatibles.",
    "Be aware that encryption always increases the file size." : "Tenga presente que la encripción siempre incrementa el tamaño del archivo.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Es siempre bueno crear copias de seguridad de sus datos, en el caso del cifrado, asegúrese de tener una copia de seguridad de las claves de cifrado junto con sus datos.",
    "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final. ¿Realmente quiere activar el cifrado?",
    "Enable encryption" : "Habilitar cifrado",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado el modulo de cifrado. Por favor habilite un modulo de cifrado en el menú de aplicaciones.",
    "Select default encryption module:" : "Seleccione el módulo de cifrado por defecto:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Necesita migrar sus claves de cifrado provenientes del antiguo sistema (ownCloud <= 8.0) al nuevo. Por favor habilite el \"Módulo de cifrado por defecto\" y ejecute 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Se necesita migrar las claves de cifrado del antiguo sistema (ownCloud <= 8.0) al nuevo sistema.",
    "Start migration" : "Iniciar migración",
    "This is used for sending out notifications." : "Esto se usa para enviar notificaciones.",
    "Send mode" : "Modo de envío",
    "Encryption" : "Cifrado",
    "From address" : "Desde la dirección",
    "mail" : "correo electrónico",
    "Authentication method" : "Método de autenticación",
    "Authentication required" : "Se necesita autenticación",
    "Server address" : "Dirección del servidor",
    "Port" : "Puerto",
    "Credentials" : "Credenciales",
    "SMTP Username" : "Nombre de usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Store credentials" : "Almacenar credenciales",
    "Test email settings" : "Probar configuración de correo electrónico",
    "Send email" : "Enviar mensaje",
    "Download logfile" : "Descargar archivo de registro",
    "More" : "Más",
    "Less" : "Menos",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "El archivo de registro es mayor de 100 MB. Descargarlo puede tardar.",
    "What to log" : "Que registrar",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Se utiliza SQLite como base de datos. Para instalaciones mas grandes se recomiende cambiar a otro sistema de base de datos. ",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "El uso de SQLite está desaconsejado especialmente cuando se usa el cliente de escritorio para sincronizar los ficheros.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Para migrar a otra base de datos usa la herramienta de línea de comandos 'occ db:convert-type' o mira la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentación ↗</a>.",
    "How to do backups" : "Cómo hacer copias de seguridad",
    "Advanced monitoring" : "Monitorización avanzada",
    "Performance tuning" : "Ajuste de rendimiento",
    "Improving the config.php" : "Mejorar el config.php",
    "Theming" : "Personalizar el tema",
    "Hardening and security guidance" : "Guía de protección y seguridad",
    "Version" : "Versión",
    "Developer documentation" : "Documentación de desarrollador",
    "Experimental applications ahead" : "Aplicaciones experimentales más adelante",
    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Las aplicaciones experimentales no están verificadas por problemas de seguridad, recientes o conocidas por ser inestables y/o bajo un fuerte desarrollo. Instalándolas pueden causar pérdida de datos o violación de seguridades.",
    "by %s" : "por %s",
    "%s-licensed" : "Licencia %s",
    "Documentation:" : "Documentación:",
    "User documentation" : "Documentación de usuario",
    "Admin documentation" : "Documentación de administrador",
    "Visit website" : "Visite nuestro sitio web",
    "Report a bug" : "Notificar un error",
    "Show description …" : "Mostrar descripción…",
    "Hide description …" : "Ocultar descripción…",
    "This app has an update available." : "Está app tiene una actualización pendiente.",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Esta aplicación no tiene ninguna versión mínima de ownCloud asignada. Este será un error en ownCloud 11 y posteriores.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Esta aplicación no tiene ninguna versión máxima de ownCloud asignada. Este será un error en ownCloud 11 y posteriores.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede instalarse porque las siguientes dependencias no están cumplimentadas:",
    "Enable only for specific groups" : "Activar solamente para grupos específicos",
    "Uninstall App" : "Desinstalar aplicación",
    "Enable experimental apps" : "Habilitar aplicaciones experimentales",
    "SSL Root Certificates" : "Raíz de certificados SSL  ",
    "Common Name" : "Nombre común",
    "Valid until" : "Válido hasta",
    "Issued By" : "Emitido por",
    "Valid until %s" : "Válido hasta %s",
    "Import root certificate" : "Importar certificado raíz",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "¿Qué tal?,<br><br>este mensaje es para hacerle saber que ahora tiene una %s cuenta.<br><br>Su nombre de usuario: %s<br>Acceda en: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "¡Saludos!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hola, ¿qué tal?,\n\nEste mensaje es para hacerle saber que ahora tiene una cuenta %s.\n\nSu nombre de usuario: %s\nAcceda en: %s\n\n",
    "Administrator documentation" : "Documentación del adminsitrador",
    "Online documentation" : "Documentación en línea",
    "Forum" : "Foro",
    "Issue tracker" : "Seguidor de problemas:",
    "Commercial support" : "Soporte Comercial",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Estas usando <strong>%s</strong> de <strong>%s</strong> ",
    "Profile picture" : "Foto de perfil",
    "Upload new" : "Subir otra",
    "Select from Files" : "Seleccionar desde Archivos",
    "Remove image" : "Borrar imagen",
    "png or jpg, max. 20 MB" : "png o jpg, max. 20 MB",
    "Picture provided by original account" : "Imagen provista por cuenta original",
    "Cancel" : "Cancelar",
    "Choose as profile picture" : "Seleccionar como imagen de perfil",
    "Full name" : "Nombre completo",
    "No display name set" : "No se ha establecido ningún nombre para mostrar",
    "Email" : "Correo electrónico",
    "Your email address" : "Su dirección de correo",
    "For password recovery and notifications" : "Para la recuperación de contraseña y notificaciones",
    "No email address set" : "Ninguna dirección de correo establecida",
    "You are member of the following groups:" : "Es miembro de los siguientes grupos:",
    "Password" : "Contraseña",
    "Unable to change your password" : "No se ha podido cambiar su contraseña",
    "Current password" : "Contraseña actual",
    "New password" : "Nueva contraseña",
    "Change password" : "Cambiar contraseña",
    "Language" : "Idioma",
    "Help translate" : "Ayúdanos a traducir",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Estos son los clientes en web, en escritorio y en móvil actualmente conectados en su OwnCloud.",
    "Browser" : "Navegador",
    "Most recent activity" : "Actividad más reciente",
    "You've linked these apps." : "Has enlazado estas apps.",
    "Name" : "Nombre",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Una contraseña de app es un código que proporciona permisos a una app o dispositivo para acceder a tu cuenta %s.",
    "App name" : "nombre de la app",
    "Create new app password" : "Crear una nueva contraseña en la app",
    "Use the credentials below to configure your app or device." : "Use la contraseña generada para configurar su app o dispositivo.",
    "Username" : "Nombre de usuario",
    "Done" : "Hecho",
    "Get the apps to sync your files" : "Obtener las aplicaciones para sincronizar sus archivos",
    "Desktop client" : "Cliente de escritorio",
    "Android app" : "Aplicación de Android",
    "iOS app" : "La aplicación de iOS",
    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Si quiere colaborar con el proyecto\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">participe en el desarrollo</a>\n\t\to\n\t\t¡<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">difúndalo</a>!",
    "Show First Run Wizard again" : "Mostrar nuevamente el Asistente de ejecución inicial",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Desarrollado por la {communityopen}comunidad ownCloud{linkclose}, el {githubopen}código fuente{linkclose} está bajo la licencia {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Show storage location" : "Mostrar la ubicación del almacenamiento",
    "Show last log in" : "Mostrar el último inicio de sesión",
    "Show user backend" : "Mostrar motor de usuario",
    "Send email to new user" : "Enviar correo al usuario nuevo",
    "Show email address" : "Mostrar dirección de correo electrónico",
    "E-Mail" : "Correo electrónico",
    "Create" : "Crear",
    "Admin Recovery Password" : "Recuperación de la contraseña de administración",
    "Enter the recovery password in order to recover the users files during password change" : "Introduzca la contraseña de recuperación a fin de recuperar los archivos de los usuarios durante el cambio de contraseña.",
    "Add Group" : "Agregar grupo",
    "Group" : "Grupo",
    "Everyone" : "Todos",
    "Admins" : "Administradores",
    "Default Quota" : "Cuota predeterminada",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Por favor indique la cúota de almacenamiento (ej: \"512 MB\" o \"12 GB\")",
    "Other" : "Otro",
    "Full Name" : "Nombre completo",
    "Group Admin for" : "Grupo administrador para",
    "Quota" : "Cuota",
    "Storage Location" : "Ubicación de almacenamiento",
    "User Backend" : "Motor de usuario",
    "Last Login" : "Último inicio de sesión",
    "change full name" : "cambiar el nombre completo",
    "set new password" : "establecer nueva contraseña",
    "change email address" : "cambiar dirección de correo electrónico",
    "Default" : "Predeterminado"
},
"nplurals=2; plural=(n != 1);");
